<?php

namespace Schaffen\Transaction\Transaction\Models;


use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Schaffen\Core\Company\Models\Branch;
use Schaffen\Core\Company\Models\CostCenter;
use Schaffen\Core\Company\Traits\HasBranch;
use Schaffen\Core\Person\Models\Person;
use Schaffen\Core\Person\Traits\HasPerson;

class Transaction extends Model
{

   use SoftDeletes, HasBranch, HasPerson;

   const ENTRADA = 'ENTRADA';
   const SAIDA = 'SAIDA';
   const TRANSFERENCIA = 'TRANSFERENCIA';
   const VENDA = 'VENDA';
   const ORDEM_SERVICO = 'ORDEMSERVICO';
   const DEVOLUCAO = 'DEVOLUCAO';
   const DEVOLUCAO_ENTRADA = 'DEVOLUCAO_ENTRADA';
   const DEVOLUCAO_SAIDA = 'DEVOLUCAO_SAIDA';
   const MOV_COMPOSICAO = 'MOV_COMPOSICAO';
   const LOCACAO = 'LOCACAO';
   const BONIFICACAO = 'BONIFICACAO';
   const PEDIDO = 'PEDIDO';
   const REMESSA = 'REMESSA';
   const PEDIDO_ORDEM_SERVICO = 'PEDIDO_ORDEM_SERVICO';

   const CREATED_AT = 'trn_created_at';
   const UPDATED_AT = 'trn_updated_at';
   const DELETED_AT = 'trn_deleted_at';

   public $timestamps = true;
   protected $connection = 'dynamicdb';
   protected $table = "transacao.transacao";
   protected $primaryKey = "trn_codigo";
   protected $prefix = "trn";
   protected $fillable = [
      "trn_tipo",
      "trn_hash",
      "trn_cliente_identificacao",
      "trn_obervacao",
      "trn_fk_fil_codigo",
      "trn_desconto_geral",
      "trn_tipo_pagamento",
      "trn_entrega_balcao",
      "trn_tipo_pagamento",
      "trn_entrega_balcao",
      "trn_fk_ccu_codigo",
      "trn_sentido_consignacao",
      "trn_fk_loe_estoque_consignacao"
   ];

   protected $dates = [
      "trn_created_at",
      "trn_updated_at",
      "trn_deleted_at"
   ];

   public function person()
   {
      return $this->belongsTo(Person::class, "trn_cliente_fk_pes_codigo");
   }

   public function filial()
   {
      return $this->belongsTo(Branch::class, "trn_fk_fil_codigo", "fil_codigo");
   }

   public function centro_custo()
   {
      return $this->belongsTo(CostCenter::class, "trn_fk_ccu_codigo", "ccu_codigo");
   }
}
